@@ -23,9 +23,9 @@ SIMPLES = {
     "sketches_simple":        "sketches"
     }
 
-__all__ = list(STANDAR.keys()).extend(list(SIMPLES.keys()))
+__all__ = ['disc']
 
-def disc(G, algo='sketches_simple', verbose = False, all_pairs = False,*args, **kwargs):
+def disc(G, algo='sketches_simple', verbose = False, all_terms = False, *args, **kwargs):
     """Compute the DIS-C graph. This function can compute the DIS-C distance between pairs
     of concepts.
     
@@ -42,7 +42,7 @@ def disc(G, algo='sketches_simple', verbose = False, all_pairs = False,*args, **
     verbose : bool
         To see the verbose.
 
-    all_pairs : bool
+    all_terms : bool
         To compute the dis-c distance between whole pairs of concepts in the graph G.
 
     Return
@@ -108,7 +108,7 @@ def disc(G, algo='sketches_simple', verbose = False, all_pairs = False,*args, **
             total_weight += w_ab + w_ba
         if verbose:
             print(" Computing thresholds ...")
-        curEPS = _compute(disc_graph, G, algo, **kwargs)
+        curEPS = _compute(disc_graph, algo, all_terms=all_terms **kwargs)
         eps = (oldEPS - curEPS)**2
         oldEPS = curEPS
         if verbose:
@@ -164,7 +164,7 @@ def get_disc(disc, term_a, term_b):
 
 
 
-def _compute(disc, algo, **kwargs):
+def _compute(disc, algo, all_terms, **kwargs):
     """Redirect the computing of the DIS-C distnace.
 
     Params.
@@ -180,9 +180,9 @@ def _compute(disc, algo, **kwargs):
     The average of the generality reached in the actual iteration.
     """
     if algo in STANDAR:
-         ret_val = _standard(disc, algo,  **kwargs)
+         ret_val = _standard(disc, algo, all_terms=all_terms  **kwargs)
     elif algo in SIMPLES:
-        ret_val = _simples(disc, algo, **kwargs)
+        ret_val = _simples(disc, algo, all_terms=all_terms, **kwargs)
     else:
         raise ValueError("Algorithm in params does not exist. Please use: dijkstra, pruned_dijkstra,\
         sketche, pruned_dijkstra_simple or sketches_simple")
